
var inputHasFocus = false;

/**
 * Updates the group parameters and display.
 * @param  {object} group the group data
 */
function updateGroup(group) {
    if (typeof(group) !== 'object') {
        console.log("unexpected data " + typeof(group));
        return;
    }

    curEdit.obj = group;
    curEdit.obj.id = groupId;
    curEdit.obj.type = TYPE_GROUP;
    curEdit.obj.state = group.action; // groups use "action" instead of "state"
    curEdit.obj.hasColor = true;
    curEdit.obj.hue = 0;

    curEdit.sat = curEdit.obj.state.sat;
    curEdit.hue = curEdit.obj.state.hue / 65535;
    mapLevelToPercent(curEdit.obj);
    mapSatToPercent(curEdit.obj);
    showLightEditPage();
}

/**
 * Updates the light parameters and display.
 * @param  {object} light the light data
 */
function updateLight(light) {
    if (typeof(light) !== 'object') {
        console.log("unexpected data " + typeof(light));
        return;
    }

    curEdit.obj = light;
    curEdit.obj.id = lightId;
    curEdit.obj.type = TYPE_LIGHT;
    curEdit.obj.hasColor = true; // TODO
    curEdit.obj.hue = 0;

    curEdit.sat = curEdit.obj.state.sat;
    curEdit.hue = curEdit.obj.state.hue / 65535;
    mapLevelToPercent(curEdit.obj);
    mapSatToPercent(curEdit.obj);
    showLightEditPage();
}

function loadGroup() {
    var etag = "unknown";

    if (curEdit.obj.etag) {
        etag = '"' + curEdit.obj.etag + '"';
    }

    $.ajax({
        url: '/api/' + apikey + '/groups/' + groupId,
        type: 'GET',
        headers: {
            'If-None-Match': etag,
            'Accept': apiversion
        },
        success: function(json, status, xhr) {
            if (xhr.status === 304) {
                return;
            }
            updateGroup(json);
        },
        error: function(jqXHR, textStatus, errorThrown) {
            console.log("textStatus:", textStatus + ' ' + errorThrown);
            console.log(jqXHR.responseText);
            loadGroup();
        },
        timeout: 10000
    });
}

function loadLight() {
    var etag = "unknown";

    if (curEdit.obj.etag) {
        etag = '"' + curEdit.obj.etag + '"';
    }

    $.ajax({
        url: '/api/' + apikey + '/lights/' + lightId,
        type: 'GET',
        headers: {
            'If-None-Match': etag,
            'Accept': apiversion
        },
        success: function(json, status, xhr) {
            if (xhr.status === 304) {
                return;
            }

            updateLight(json);
        },
        error: function(jqXHR, textStatus, errorThrown) {
            console.log("textStatus:", textStatus + ' ' + errorThrown);
            console.log(jqXHR.responseText);
            loadLight();
        },
        timeout: 10000
    });
}

function handleOrientation(mediaQueryList) {
    if (mediaQueryList.matches) {
        // pageLightEdit.style.opacity = 1;
        if (pageLightEdit.style.opacity !== 1) {
            location.reload();
        }
    }
    else {
        if (!inputHasFocus) {
            pageLightEdit.style.opacity = 0;
            $('#pageLightEditLandscape').css('display', 'block');
        }
    }
}

$(document).ready(function() {
    lightControlInit();

    $('input').blur();

    // cache DOM values
    winInnerWidth = window.innerWidth;
    winInnerHeight = window.innerHeight;

    barSat = document.getElementById("barSat");
    barLevel = document.getElementById("barLevel");
    barLevelBig = document.getElementById("barLevelBig");
    closeEditLightsButton = document.getElementById("closeEditLightsButton");
    footer = document.querySelector('#pageLightEdit .footer');

  //$(document).on('vmousedown', onBigMapTouchStart);
  //$(document).on('vmousemove', onBigMapTouchMove);
  //$(document).on('vmouseup', onBigMapTouchEnd);

    // $('#backToMainButton').on('vmouseup', function(){
    //     history.back();
    // });

//    $(document).on('vclick', onSceneEditClick);

    devNameLabel = document.getElementById('devNameLabel');

    $(devNameLabel).on('focus', function() {
       inputHasFocus = true;
    });

    $(devNameLabel).on('blur', function() {
       inputHasFocus = false;
    });

    if (sessionStorage.config) {
        config = JSON.parse(sessionStorage.config);
    }

    initEditPage();
    adjustLevelEditPage();

    // show the page now (was hidden to prevent flickering while setup geometry of elements)

    var mqOrientation = window.matchMedia("(orientation: portrait)");
    // The Listener will fire whenever this either matches or ceases to match
    mqOrientation.addListener(handleOrientation);

    if (!mqOrientation.matches) {
        pageLightEdit.style.opacity = 0;
        $('#pageLightEditLandscape').css('display', 'block');
        return;
    }

    groupId = getURLParameter("group");
    lightId = getURLParameter("light");

    if (groupId !== null) {
        // load from cache
        if (config && config.groups) {
            if (groupId in config.groups) {
                updateGroup(config.groups[groupId]);
            }
        }

        loadGroup();
    }
    else if (lightId !== null) {

        // load from cache
        if (config && config.lights) {
            if (lightId in config.lights) {
                updateLight(config.lights[lightId]);
            }
        }

        loadLight();
    }
});