
function displaySetting(config) {
    $('#gwSwVersion').text(config.config.swversion);
    $('#gwNameInput').val(config.config.name);
    $('#gwGroupDelayInput').val(config.config.groupdelay);

    var discovery = config.config.discovery;

    if (discovery === true) {
        $('#internetServiceCheckbox').attr('checked', 'checked');
    }
    else {
        $('#internetServiceCheckbox').removeAttr('checked');
    }

    var curVersion = config.config.swversion;
    var updateVersion = config.config.swupdate.version;
    
    if (compareVersionNumbers(curVersion, updateVersion) === -1)
    {
        var updateTxt = '<button class="btn" type="bytton" onclick="updateSoftware(); return false;"><b>update to</b> ' + config.config.swupdate.version + ' </button>';
        $('#gwSwUpdate').html(updateTxt);
    }
}

function updateSoftware() {
        $.ajax({
        url: 'api/' + apikey + '/config/update',
        type: 'POST',
        success: function(json) {
            showAlert('alert-success', '<b>OK!</b> Starting software update. This may take up serval minutes.');
        },
        error: function(jqXHR, textStatus, errorThrown) {
            showAlert('alert-error', '<b>Error!</b> Software update failed, please try again later.');
        }
    });
}

function getFullConfiguration() {

    $.ajax({
        url: 'api/' + apikey,
        dataType: 'json',
        type: 'GET',
        contentType: 'application/json; charset=utf-8',
        success: function(json) {
            clearAlert();
            displaySetting(json);
        },
        error: function(jqXHR, textStatus, errorThrown) {
            switch (jqXHR.status) {
            case 403:
                window.location.assign("/login.html");
                break;

            default:
                setTimeout(getFullConfiguration, 1000);
                showAlert('alert-error', '<b>Error!</b> Lost connection, retry in one second ...');
                break;
            }
        },
        timeout: 3000
    });

}

function unlockGateway(seconds) {

    var params = { "unlock" : seconds };

    clearAlert();

    $.ajax({
        url: 'api/' + apikey + '/config',
        dataType: 'json',
        type: 'PUT',
        contentType: 'application/json; charset=utf-8',
        data: JSON.stringify(params),
        success: function(json) {
            showAlert('alert-success', '<b>OK!</b> Unlocked gateway for ' + seconds + ' seconds.');
        },
        error: function(jqXHR, textStatus, errorThrown) {
            showAlert('alert-error', '<b>Error!</b> Unlock gateway failed!');
        }
    });
}

function showChangePasswordAlert(alert, text) {
    var txt = "";

    txt += '<div class="alert ' + alert + '">';
    txt += text;
    txt += '</div>';

    $('#changePasswordAlert').html(txt);
}

$('#changePasswordModal').on('show', function () {
    // clear alert
    $('#oldPasswordInput').val(""); 
    $('#newPasswordInput').val(""); 
    $('#confirmPasswordInput').val(""); 
    $('#changePasswordAlert').html(""); 
})

// check if user did specify a name
function sendChangePassword() {
    clearAlert();
    var oldpw = $('#oldPasswordInput').val();
    var newpw = $('#newPasswordInput').val();
    var confpw = $('#confirmPasswordInput').val();

    if (oldpw.length === 0) {
        showChangePasswordAlert('alert-error', 'Old password not specified!')
    }
    else if (newpw.length < 5) {
        showChangePasswordAlert('alert-error', 'New password must have at least 5 characters!')
    }
    else if (newpw.length === 0) {
        showChangePasswordAlert('alert-error', 'New password not specified!')
    }
    else if (newpw !== confpw) {
        showChangePasswordAlert('alert-error', 'New and confirm password differ!')
    }
    else {
        $('#changePasswordModal').modal('hide');

        var username = "delight"; // fixed
        // combine and base64 encode username:password as in HTTP basic authentification
        var oldhash = Base64.encode(username + ':' + oldpw);
        var newhash = Base64.encode(username + ':' + newpw);

        var params = {
            "username": username,
            "oldhash": oldhash,
            "newhash": newhash
        };

        $.ajax({
            url: 'api/' + apikey + '/config/password',
            dataType: 'json',
            type: 'PUT',
            contentType: 'application/json; charset=utf-8',
            //processData: false,
            data: JSON.stringify(params),
            success: function(json) {
                showAlert('alert-success', '<b>OK!</b> Changed password.');
            },
            error: function(jqXHR, textStatus, errorThrown) {
                if (jqXHR.status === 401) {
                    showAlert('alert-error', '<b>Error!</b> Changing password failed, old password wrong!');
                }
                else {
                   showAlert('alert-error', '<b>Error!</b> Changing password failed!');
                }
            }
        });
    }
}

function sendConfig() {
    var params = { };

    clearAlert();

    params.name = $('#gwNameInput').val();
    params.groupdelay = $('#gwGroupDelayInput').val();
    params.discovery = false;

    if (params.name.length === 0) {
      showAlert('alert-error', '<b>Abort!</b> Gateway name not specified.');
      return;
    }

    if ($('#internetServiceCheckbox').prop('checked')) {
        params.discovery = true;
    }

    $.ajax({
        url: 'api/' + apikey + '/config',
        dataType: 'json',
        type: 'PUT',
        contentType: 'application/json; charset=utf-8',
        //processData: false,
        data: JSON.stringify(params),
        success: function(json) {
            showAlert('alert-success', '<b>OK!</b> Updated settings.');
        },
        error: function(jqXHR, textStatus, errorThrown) {
            showAlert('alert-error', '<b>Error!</b> Updating settings failed!');
        }
    });
}

$(document).ready(function() {
    //$('#sys-tabs').removeClass('tabs-left');
    getFullConfiguration();
});
